==> boto3_type_annotations-0.2.4.tar.gz: boto3_type_annotations-0.2.4/boto3_type_annotations/shield/client.py <==
from typing import Optional
from typing import Union
from typing import List
from botocore.waiter import Waiter
from botocore.paginate import Paginator
from typing import Dict
from botocore.client import BaseClient


class Client(BaseClient):
    def associate_drt_log_bucket(self, LogBucket: str) -> Dict:
        pass

    def associate_drt_role(self, RoleArn: str) -> Dict:
        pass

    def can_paginate(self, operation_name: str = None):
        pass

    def create_protection(self, Name: str, ResourceArn: str) -> Dict:
        pass

    def create_subscription(self) -> Dict:
        pass

    def delete_protection(self, ProtectionId: str) -> Dict:
        pass

    def delete_subscription(self) -> Dict:
        pass

    def describe_attack(self, AttackId: str) -> Dict:
        pass

    def describe_drt_access(self) -> Dict:
        pass

    def describe_emergency_contact_settings(self) -> Dict:
        pass

    def describe_protection(self, ProtectionId: str) -> Dict:
        pass

    def describe_subscription(self) -> Dict:
        pass

    def disassociate_drt_log_bucket(self, LogBucket: str) -> Dict:
        pass

    def disassociate_drt_role(self) -> Dict:
        pass

    def generate_presigned_url(self, ClientMethod: str = None, Params: Dict = None, ExpiresIn: int = None, HttpMethod: str = None):
        pass

    def get_paginator(self, operation_name: str = None) -> Paginator:
        pass

    def get_subscription_state(self) -> Dict:
        pass

    def get_waiter(self, waiter_name: str = None) -> Waiter:
        pass

    def list_attacks(self, ResourceArns: List = None, StartTime: Dict = None, EndTime: Dict = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        pass

    def list_protections(self, NextToken: str = None, MaxResults: int = None) -> Dict:
        pass

    def update_emergency_contact_settings(self, EmergencyContactList: List = None) -> Dict:
        pass

    def update_subscription(self, AutoRenew: str = None) -> Dict:
        pass

==> boto3_type_annotations-0.3.0.tar.gz: boto3_type_annotations-0.3.0/boto3_type_annotations/shield/client.py <==
from typing import Optional
from typing import List
from botocore.client import BaseClient
from botocore.paginate import Paginator
from typing import Dict
from typing import Union
from botocore.waiter import Waiter


class Client(BaseClient):
    def associate_drt_log_bucket(self, LogBucket: str) -> Dict:
        pass

    def associate_drt_role(self, RoleArn: str) -> Dict:
        pass

    def can_paginate(self, operation_name: str = None):
        pass

    def create_protection(self, Name: str, ResourceArn: str) -> Dict:
        pass

    def create_subscription(self) -> Dict:
        pass

    def delete_protection(self, ProtectionId: str) -> Dict:
        pass

    def delete_subscription(self) -> Dict:
        pass

    def describe_attack(self, AttackId: str) -> Dict:
        pass

    def describe_drt_access(self) -> Dict:
        pass

    def describe_emergency_contact_settings(self) -> Dict:
        pass

    def describe_protection(self, ProtectionId: str = None, ResourceArn: str = None) -> Dict:
        pass

    def describe_subscription(self) -> Dict:
        pass

    def disassociate_drt_log_bucket(self, LogBucket: str) -> Dict:
        pass

    def disassociate_drt_role(self) -> Dict:
        pass

    def generate_presigned_url(self, ClientMethod: str = None, Params: Dict = None, ExpiresIn: int = None, HttpMethod: str = None):
        pass

    def get_paginator(self, operation_name: str = None) -> Paginator:
        pass

    def get_subscription_state(self) -> Dict:
        pass

    def get_waiter(self, waiter_name: str = None) -> Waiter:
        pass

    def list_attacks(self, ResourceArns: List = None, StartTime: Dict = None, EndTime: Dict = None, NextToken: str = None, MaxResults: int = None) -> Dict:
        pass

    def list_protections(self, NextToken: str = None, MaxResults: int = None) -> Dict:
        pass

    def update_emergency_contact_settings(self, EmergencyContactList: List = None) -> Dict:
        pass

    def update_subscription(self, AutoRenew: str = None) -> Dict:
        pass
